searchData={"items":[{"type":"module","title":"Crono","doc":"Crono is a library to work with cron expressions.  \n\nIt parses cron expressions, allows calculating future runs of the schedule, and representing an\nexpression as a human-readable description.","ref":"Crono.html"},{"type":"module","title":"Basic usage - Crono","doc":"```elixir\niex> Crono.parse(\"5 * * * *\")\n{:ok, %Crono.Expression{minute: 5, hour: :*, day: :*, month: :*, weekday: :*}}\n\niex> ~e[5 * * * *]\n%Crono.Expression{minute: 5, hour: :*, day: :*, month: :*, weekday: :*}\n\niex> Crono.Schedule.get_next_date(~e[5 * * * *], ~N[2023-09-01T10:00:00])\n~N[2023-09-01T10:05:00]\n```","ref":"Crono.html#module-basic-usage"},{"type":"module","title":"Installation - Crono","doc":"To start off, add `crono` to the list of your dependencies:\n```elixir\ndef deps do\n  {:crono, \"~> 0.1\"},\nend\n```\n\nIf you want to use the `~e[]` sigil for your expressions, also add `import Crono.Expression` to\nyour module.","ref":"Crono.html#module-installation"},{"type":"function","title":"Crono.parse/1","doc":"Parses a cron expression, returning a `Crono.CronExpression` struct if successful.","ref":"Crono.html#parse/1"},{"type":"function","title":"Examples - Crono.parse/1","doc":"```elixir\niex> Crono.parse(\"* * * * *\")\n{:ok, %Crono.Expression{minute: :*, hour: :*, day: :*, month: :*, weekday: :*}}\n\niex> Crono.parse(\"5 * * * *\")\n{:ok, %Crono.Expression{minute: 5, hour: :*, day: :*, month: :*, weekday: :*}}\n\niex> Crono.parse(\"5/10 * * * *\")\n{:ok,%Crono.Expression{minute: [step: {5, 10}], hour: :*, day: :*, month: :*, weekday: :*}}\n\niex> Crono.parse(\"15-45 * * * *\")\n{:ok, %Crono.Expression{minute: [range: {15, 45}], hour: :*, day: :*, month: :*, weekday: :*}}\n\niex> Crono.parse(\"15,45 * * * *\")\n{:ok, %Crono.Expression{minute: [list: [15, 45]], hour: :*, day: :*, month: :*, weekday: :*}}\n\niex> Crono.parse(\"15,45 */6 14,28 * *\")\n{:ok, %Crono.Expression{minute: [list: [15, 45]], hour: [step: {:*, 6}], day: [list: [14, 28]], month: :*, weekday: :*}}\n\niex> Crono.parse(\"0 0 1 JAN *\")\n{:ok, %Crono.Expression{minute: 0, hour: 0, day: 1, month: 1, weekday: :*}}\n\niex> Crono.parse(\"0 0 * * WED\")\n{:ok, %Crono.Expression{minute: 0, hour: 0, day: :*, month: :*, weekday: 3}}\n```","ref":"Crono.html#parse/1-examples"},{"type":"function","title":"Crono.parse!/1","doc":"Like `Crono.parse/1`, but raises on error.","ref":"Crono.html#parse!/1"},{"type":"module","title":"Crono.Expression","doc":"A parsed cron expression.","ref":"Crono.Expression.html"},{"type":"function","title":"Crono.Expression.sigil_e/2","doc":"Sigil to parse an input and create a `Crono.Expression`.","ref":"Crono.Expression.html#sigil_e/2"},{"type":"function","title":"Examples - Crono.Expression.sigil_e/2","doc":"```elixir\niex> ~e[*/15 * * * *]\n%Crono.Expression{minute: [step: {:*, 15}], hour: :*, day: :*, month: :*, weekday: :*}\n```","ref":"Crono.Expression.html#sigil_e/2-examples"},{"type":"type","title":"Crono.Expression.t/0","doc":"","ref":"Crono.Expression.html#t:t/0"},{"type":"type","title":"Crono.Expression.value/1","doc":"","ref":"Crono.Expression.html#t:value/1"},{"type":"module","title":"Crono.Schedule","doc":"Functions to work with cron schedules.","ref":"Crono.Schedule.html"},{"type":"function","title":"Crono.Schedule.get_next_date/2","doc":"Calculates the next scheduled run given a `Crono.Expression` and a date (defaulting to now).","ref":"Crono.Schedule.html#get_next_date/2"},{"type":"function","title":"Examples - Crono.Schedule.get_next_date/2","doc":"```elixir\niex> get_next_date(~e[0 0 * * *], ~N[2023-09-01T15:00:00])\n~N[2023-09-02T00:00:00]\n```","ref":"Crono.Schedule.html#get_next_date/2-examples"},{"type":"function","title":"Crono.Schedule.get_next_dates/3","doc":"Calculates the next few scheduled runs given a `Crono.Expression`, a date (defaulting to now) and\na count.","ref":"Crono.Schedule.html#get_next_dates/3"},{"type":"function","title":"Examples - Crono.Schedule.get_next_dates/3","doc":"```elixir\niex> get_next_dates(~e[0 0 * * *], ~N[2023-09-01T15:00:00], 3)\n[~N[2023-09-02T00:00:00], ~N[2023-09-03T00:00:00], ~N[2023-09-04T00:00:00]]\n```","ref":"Crono.Schedule.html#get_next_dates/3-examples"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"0.1.0 (2023-09-16) - Changelog","doc":"#","ref":"changelog.html#0-1-0-2023-09-16"},{"type":"extras","title":"Features - Changelog","doc":"* initial release","ref":"changelog.html#features"}],"content_type":"text/markdown"}